@@ -16,7 +16,11 @@
     <name>BusyPane</name>
     <message>
         <source>updating...</source>
-        <translation>aktualizacja...</translation>
+        <translation type="obsolete">aktualizacja...</translation>
+    </message>
+    <message>
+        <source>Updating...</source>
+        <translation>Aktualizacja...</translation>
     </message>
 </context>
 <context>
@@ -83,6 +87,10 @@
         <source>Enable GPS</source>
         <translation>Włącz GPS</translation>
     </message>
+    <message>
+        <source>Choose your language:</source>
+        <translation>Wybierz swój język:</translation>
+    </message>
 </context>
 <context>
     <name>SplashPane</name>
